@@ -29,6 +29,8 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <eel/eel-string.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
+#include <libnautilus-private/nautilus-thumbnails.h>
 
 #include "fm-icon-container.h"
 
@@ -42,16 +44,16 @@ GNOME_CLASS_BOILERPLATE (FMIconContainer, fm_icon_container,
 static FMIconView *
 get_icon_view (NautilusIconContainer *container)
 {
-	g_assert (FM_IS_ICON_CONTAINER (container));
-
-	return FM_ICON_CONTAINER (container)->view;
+	/* Type unsafe comparison for performance */
+	return ((FMIconContainer *)container)->view;
 }
 
 static char *
 fm_icon_container_get_icon_images (NautilusIconContainer *container,
 				   NautilusIconData      *data,
 				   GList                **emblem_icons,
-				   char                 **embedded_text)
+				   char                 **embedded_text,
+				   gboolean              *embedded_text_needs_loading)
 {
 	FMIconView *icon_view;
 	EelStringList *emblems_to_ignore;
@@ -64,7 +66,7 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 	g_return_val_if_fail (icon_view != NULL, NULL);
 
 	if (embedded_text) {
-		*embedded_text = nautilus_file_peek_top_left_text (file);
+		*embedded_text = nautilus_file_peek_top_left_text (file, embedded_text_needs_loading);
 	}
 	
 	if (emblem_icons != NULL) {
@@ -75,9 +77,63 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 		eel_string_list_free (emblems_to_ignore);
 	}
 
-	return nautilus_icon_factory_get_icon_for_file (file);
+	return nautilus_icon_factory_get_icon_for_file (file, TRUE);
 }
 
+static void
+fm_icon_container_start_monitor_top_left (NautilusIconContainer *container,
+					  NautilusIconData      *data,
+					  gconstpointer          client)
+{
+	NautilusFile *file;
+	GList *attributes;
+
+	file = (NautilusFile *) data;
+
+	g_assert (NAUTILUS_IS_FILE (file));
+
+
+	attributes = NULL;
+	attributes = g_list_prepend (attributes,
+				     NAUTILUS_FILE_ATTRIBUTE_TOP_LEFT_TEXT);
+
+	nautilus_file_monitor_add (file, client, attributes);
+        g_list_free (attributes);
+}
+
+static void
+fm_icon_container_stop_monitor_top_left (NautilusIconContainer *container,
+					 NautilusIconData      *data,
+					 gconstpointer          client)
+{
+	NautilusFile *file;
+
+	file = (NautilusFile *) data;
+
+	g_assert (NAUTILUS_IS_FILE (file));
+
+	nautilus_file_monitor_remove (file, client);
+}
+
+static void
+fm_icon_container_prioritize_thumbnailing (NautilusIconContainer *container,
+					   NautilusIconData      *data)
+{
+	NautilusFile *file;
+	char *uri;
+
+	file = (NautilusFile *) data;
+
+	g_assert (NAUTILUS_IS_FILE (file));
+
+	if (nautilus_file_is_thumbnailing (file)) {
+		uri = nautilus_file_get_uri (file);
+		nautilus_thumbnail_prioritize (uri);
+		g_free (uri);
+	}
+}
+
+
 /*
  * Get the preference for which caption text should appear
  * beneath icons.
@@ -349,9 +405,10 @@ fm_icon_container_compare_icons (NautilusIconContainer *container,
 			(container, icon_a, icon_b);
 	}
 
+	/* Type unsafe comparisons for performance */
 	return fm_icon_view_compare_files (icon_view,
-					   NAUTILUS_FILE (icon_a),
-					   NAUTILUS_FILE (icon_b));
+					   (NautilusFile *)icon_a,
+					   (NautilusFile *)icon_b);
 }
 
 static int
@@ -387,6 +444,9 @@ fm_icon_container_class_init (FMIconContainerClass *klass)
 
 	ic_class->get_icon_text = fm_icon_container_get_icon_text;
 	ic_class->get_icon_images = fm_icon_container_get_icon_images;
+	ic_class->start_monitor_top_left = fm_icon_container_start_monitor_top_left;
+	ic_class->stop_monitor_top_left = fm_icon_container_stop_monitor_top_left;
+	ic_class->prioritize_thumbnailing = fm_icon_container_prioritize_thumbnailing;
 
 	ic_class->compare_icons = fm_icon_container_compare_icons;
 	ic_class->compare_icons_by_name = fm_icon_container_compare_icons_by_name;
