@@ -85,8 +85,7 @@ struct NautilusWindow {
         
 	char *last_geometry;
 	
-        guint status_bar_clear_id;
-        guint save_geometry_timeout_id;
+       guint save_geometry_timeout_id;
 	  
         /** CORBA-related elements **/
         NautilusApplication *application;
@@ -117,7 +116,7 @@ struct NautilusWindow {
         NautilusWindowShowState show_state;
 };
 
-GtkType          nautilus_window_get_type             (void);
+GType            nautilus_window_get_type             (void);
 void		 nautilus_window_ui_freeze	      (NautilusWindow	 *window);
 void		 nautilus_window_ui_thaw	      (NautilusWindow	 *window);
 void             nautilus_window_close                (NautilusWindow    *window);
@@ -146,8 +145,10 @@ void		 nautilus_forget_history	      (void);
 void             nautilus_bookmarks_exiting           (void);
 void		 nautilus_window_reload		      (NautilusWindow	 *window);
 gint 		 nautilus_window_get_base_page_index  (NautilusWindow 	 *window);
-void 		 nautilus_window_hide_location_bar    (NautilusWindow 	 *window);
-void 		 nautilus_window_show_location_bar    (NautilusWindow 	 *window);
+void 		 nautilus_window_hide_location_bar    (NautilusWindow 	 *window,
+                                                       gboolean           save_preference);
+void 		 nautilus_window_show_location_bar    (NautilusWindow 	 *window,
+                                                       gboolean           save_preference);
 gboolean	 nautilus_window_location_bar_showing (NautilusWindow    *window);
 void 		 nautilus_window_hide_toolbar         (NautilusWindow 	 *window);
 void 		 nautilus_window_show_toolbar         (NautilusWindow 	 *window);
